# Добро пожаловать на страницу документации vk_maria!
[![Downloads](https://pepy.tech/badge/vk-maria)](https://pepy.tech/project/vk-maria)
[![Downloads](https://pepy.tech/badge/vk-maria/month)](https://pepy.tech/project/vk-maria)
[![Downloads](https://pepy.tech/badge/vk-maria/week)](https://pepy.tech/project/vk-maria)

[![PyPi Package Version](https://img.shields.io/pypi/v/vk_maria.svg?style=flat-square)](https://pypi.python.org/pypi/vk_maria)
[![Supported python versions](https://img.shields.io/pypi/pyversions/vk_maria.svg?style=flat-square)](https://pypi.python.org/pypi/vk_maria)

**vk_maria**  сочетает в себе простоту и удобство написания кода, а также функциональность на сколько это возможно! Библиотека написана на Python 3.8 с использованием современных инструментов для разработки ботов.

# Официальные ресурсы

[Русское сообщество](https://t.me/vk_maria_ru)

[Pip](https://pypi.org/project/vk-maria/)

[Документация](https://github.com/lxstvayne/vk_maria/wiki)

[Исходники](https://github.com/lxstvayne/vk_maria)

[Issues/Bug Tracker](https://github.com/lxstvayne/vk_maria/issues)


# Достоинства

Простота разработки

Имеет [FSM (Конечные автоматы)](https://ru.wikipedia.org/wiki/%D0%9A%D0%BE%D0%BD%D0%B5%D1%87%D0%BD%D1%8B%D0%B9_%D0%B0%D0%B2%D1%82%D0%BE%D0%BC%D0%B0%D1%82)

Имеет альтернативный подход к созданию клавиатур через модели

Имеет полную типизацию

# Внести вклад

[Issue Tracker](https://github.com/lxstvayne/vk_maria/issues)

[Исходники](https://github.com/lxstvayne/vk_maria)

# Содержание

* [Установка](https://github.com/lxstvayne/vk_maria/wiki/%D0%A3%D1%81%D1%82%D0%B0%D0%BD%D0%BE%D0%B2%D0%BA%D0%B0)
* [Ваш первый бот](https://github.com/lxstvayne/vk_maria/wiki/%D0%92%D0%B0%D1%88-%D0%BF%D0%B5%D1%80%D0%B2%D1%8B%D0%B9-%D0%B1%D0%BE%D1%82)
* [Vk](https://github.com/lxstvayne/vk_maria/wiki/Vk)
* [LongPoll](https://github.com/lxstvayne/vk_maria/wiki/LongPoll)
* [Обработчики событий](https://github.com/lxstvayne/vk_maria/wiki/%D0%9E%D0%B1%D1%80%D0%B0%D0%B1%D0%BE%D1%82%D1%87%D0%B8%D0%BA%D0%B8-%D1%81%D0%BE%D0%B1%D1%8B%D1%82%D0%B8%D0%B9)
* [Аннотации](https://github.com/lxstvayne/vk_maria/wiki/%D0%90%D0%BD%D0%BD%D0%BE%D1%82%D0%B0%D1%86%D0%B8%D0%B8)
* [Upload](https://github.com/lxstvayne/vk_maria/wiki/Upload)
* [Клавиатуры](https://github.com/lxstvayne/vk_maria/wiki/%D0%9A%D0%BB%D0%B0%D0%B2%D0%B8%D0%B0%D1%82%D1%83%D1%80%D1%8B)
* [FSM (Конечные автоматы)](https://github.com/lxstvayne/vk_maria/wiki/FSM-(%D0%9A%D0%BE%D0%BD%D0%B5%D1%87%D0%BD%D1%8B%D0%B5-%D0%B0%D0%B2%D1%82%D0%BE%D0%BC%D0%B0%D1%82%D1%8B))
* [Постскриптум ](https://github.com/lxstvayne/vk_maria/wiki/%D0%9F%D0%BE%D1%81%D1%82%D1%81%D0%BA%D1%80%D0%B8%D0%BF%D1%82%D1%83%D0%BC)